sqlobject.tests.test_style module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_style module

class `sqlobject.tests.test_style.` `AnotherStyle`(pythonAttrToDBColumn=None, dbColumnToPythonAttr=None, pythonClassToDBTable=None, dbTableToPythonClass=None, idForTable=None, longID=False)

  Bases: `sqlobject.styles.MixedCaseUnderscoreStyle`

  `pythonAttrToDBColumn`(attr)

class `sqlobject.tests.test_style.` `SOStyleTest1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `a`
  `j` = so_style_test1
  `q` = so_style_test1
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_style.SOStyleTest1`

    `style` = <sqlobject.tests.test_style.AnotherStyle object>
    `table` = 'so_style_test1'
  property `st2`
  property `st2ID`

class `sqlobject.tests.test_style.` `SOStyleTest2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `b`
  `j` = so_style_test2
  `q` = so_style_test2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_style.SOStyleTest2`

    `style` = <sqlobject.tests.test_style.AnotherStyle object>
    `table` = 'so_style_test2'

`sqlobject.tests.test_style.` `test_style`()